.. image:: ../images/logo.png

-------------------------------------

Entities
-----------

Fracability is based on the access and manipulation of data enclosed in objects defined as **entities**:

.. toctree::
    :maxdepth: 1
    :glob:

    Entities/*

Each entity is build in such a way to properly modify and streamline the input data.
    1. Fracture entity objects represent fracture data
    2. Boundary entity objects represent boundary data
    3. FractureNetwork entity is the combination of Fractures and Boundaries

Using this object oriented approach flexibility is ensured. Each entity have shared and custom methods that can be
accessed.